@@ -1,12 +1,12 @@
 # ==============================================================================
-# generic method definition 
+# generic method definition
 # ==============================================================================
 
 if ( !isGeneric("call.mi")) {
   setGeneric( "call.mi",
               function(object ){
                 standardGeneric( "call.mi" )
-              } 
+              }
   )
 }
 
@@ -15,7 +15,7 @@ if ( !isGeneric("coef")) {
   setGeneric( "coef",
               function( object, ... ){
                 standardGeneric( "coef" )
-              } 
+              }
   )
 }
 
@@ -25,7 +25,7 @@ if ( !isGeneric("coefficients")) {
   setGeneric( "coefficients",
               function( object, ... ){
                 standardGeneric( "coefficients" )
-              } 
+              }
   )
 }
 
@@ -36,7 +36,7 @@ if ( !isGeneric("converged")) {
   setGeneric( "converged",
               function( object, ... ){
                 standardGeneric( "converged" )
-              } 
+              }
   )
 }
 
@@ -46,17 +46,17 @@ if ( !isGeneric( "data.mi" )) {
   setGeneric( "data.mi",
               function( object ){
                 standardGeneric( "data.mi" )
-              } 
+              }
   )
 }
 
-setGeneric("fitted")
+#setGeneric("fitted")
 
 #if ( !isGeneric( "fitted" )) {
 #  setGeneric( "fitted",
 #              function( object, ...){
 #                standardGeneric( "fitted" )
-#              } 
+#              }
 #  )
 #}
 
@@ -68,7 +68,7 @@ if ( !isGeneric( "m" )) {
   setGeneric( "m",
               function( object ){
                 standardGeneric( "m" )
-              } 
+              }
   )
 }
 
@@ -77,7 +77,7 @@ if ( !isGeneric( "bugs.mi" )) {
   setGeneric( "bugs.mi",
               function( object, ... ){
                 standardGeneric( "bugs.mi" )
-              } 
+              }
   )
 }
 
@@ -86,7 +86,7 @@ if ( !isGeneric( "info.mi" )) {
   setGeneric( "info.mi",
               function( object ){
                 standardGeneric( "info.mi" )
-              } 
+              }
   )
 }
 
@@ -95,7 +95,7 @@ if ( !isGeneric( "imp" )) {
   setGeneric( "imp",
               function( object,... ){
                 standardGeneric("imp")
-              } 
+              }
   )
 }
 
@@ -103,14 +103,14 @@ if ( !isGeneric( "is.mi" )) {
   setGeneric( "is.mi",
               function(object){
                 standardGeneric("is.mi")
-              } 
+              }
   )
 }
 
 if ( !isGeneric("mi")) {
     setGeneric( "mi",
                function(object, ...){
-               standardGeneric("mi") 
+               standardGeneric("mi")
                }
     )
 }
@@ -121,7 +121,7 @@ if ( !isGeneric( "mi.completed" )) {
   setGeneric( "mi.completed",
               function( object, ... ){
                 standardGeneric( "mi.completed" )
-              } 
+              }
   )
 }
 
@@ -130,7 +130,7 @@ if ( !isGeneric( "mi.data.frame" )) {
   setGeneric( "mi.data.frame",
               function( object,... ){
                 standardGeneric( "mi.data.frame" )
-              } 
+              }
   )
 }
 
@@ -140,14 +140,14 @@ if ( !isGeneric("imputed")) {
     setGeneric("imputed",
                function( object, ... ){
                   standardGeneric( "imputed" )
-               } 
+               }
     )
 }
 
 if ( !isGeneric("mi")) {
     setGeneric( "mi",
                function( object, ... ){
-               standardGeneric( "mi" ) 
+               standardGeneric( "mi" )
                }
     )
 }
@@ -157,7 +157,7 @@ if ( !isGeneric("mi")) {
 if ( !isGeneric("mi.hist")) {
     setGeneric( "mi.hist",
                function( object, Yobs,... ){
-               standardGeneric( "mi.hist" ) 
+               standardGeneric( "mi.hist" )
                }
     )
 }
@@ -167,7 +167,7 @@ if ( !isGeneric("mi.hist")) {
 #  setGeneric( "mi.initialize",
 #              function(object, ...){
 #              standardGeneric( "mi.initialize" )
-#              } 
+#              }
 #  )
 
 setGeneric("resid")
@@ -176,7 +176,7 @@ setGeneric("resid")
 #  setGeneric( "resid",
 #              function( object, ...){
 #                standardGeneric( "resid" )
-#              } 
+#              }
 #  )
 #}
 
@@ -186,25 +186,16 @@ setGeneric("residuals")
 #  setGeneric( "residuals",
 #              function( object, ...){
 #                standardGeneric( "residuals" )
-#              } 
+#              }
 #  )
 #}
 
-if ( !isGeneric( "sigma.hat" ) ) {
-    setGeneric( "sigma.hat",
-               function( object,... ){
-               standardGeneric( "sigma.hat" )
-               } 
-    )
-}
-
-
 
 if ( !isGeneric( "typecast" ) ) {
     setGeneric( "typecast",
                function( object ){
                standardGeneric( "typecast" )
-               } 
+               }
     )
 }
 
@@ -214,6 +205,6 @@ if ( !isGeneric( "update" )) {
   setGeneric( "update",
               function( object, ...){
                 standardGeneric( "update" )
-              } 
+              }
   )
 }
