@@ -1,8 +1,8 @@
 # ==============================================================================
-# extract fitted values 
+# extract fitted values
 # ==============================================================================
-setMethod("fitted", signature(object = "mi.method"), 
-  function(object){
-  object@expected
+
+
+fitted.mi.method <- function(object,...){
+    object@expected
 }
-)
