@@ -1,9 +1,9 @@
 # ==============================================================================
-# extract sigma.hat values 
+# extract sigma.hat values
 # ==============================================================================
 
-setMethod("sigma.hat", signature( object = "mi.method"),     
-  function (object) {
+
+
+sigma.hat.mi.method <- function(object,...){
     object@model$sigma
-  }
-)
+}
